@@ -1,9 +1,9 @@
 package App::FileRemoveUtils;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2020-05-30'; # DATE
+our $DATE = '2020-06-03'; # DATE
 our $DIST = 'App-FileRemoveUtils'; # DIST
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 use 5.010001;
 use strict;
@@ -66,7 +66,9 @@ sub delete_all_empty_files {
         }
     }
 
-    [200];
+    [200, "OK", undef, {
+        'func.files' => \@files,
+    }];
 }
 
 $SPEC{delete_all_empty_dirs} = {
@@ -148,7 +150,7 @@ App::FileRemoveUtils - Utilities related to removing/deleting files
 
 =head1 VERSION
 
-This document describes version 0.002 of App::FileRemoveUtils (from Perl distribution App-FileRemoveUtils), released on 2020-05-30.
+This document describes version 0.003 of App::FileRemoveUtils (from Perl distribution App-FileRemoveUtils), released on 2020-06-03.
 
 =head1 DESCRIPTION
 
